function r = ExpBSplineF(gamma)
% r = ExpBSplineF(gamma)
%
% Returns the exponential B-Spline scaling filter
% of parameter gamma, WITHOUT the 2^(1-M) factor,
% where M = length(gamma).
%
% gamma: Row-vector defining the exponential B-spline.
%
% r:     Scaling filter.
%
% (c) Cedric Vonesch, Biomedical Imaging Group, EPFL, 2006.07.19-2010.11.29

r = 1;
while numel(gamma) > 0
	gamma_m = gamma(1);
	alpha = real(gamma_m);
	cosomega0 = cos(imag(gamma_m));
	loc = (gamma == gamma_m);
	L_m = sum(loc);
	if abs(cosomega0) < 1
		locstr = (gamma == conj(gamma_m));
		if L_m ~= sum(locstr)
			error('gamma does not correspond to a real-valued filter.');
		else
			r_m = [1, 2*exp(alpha)*cosomega0, exp(2*alpha)];
			for ell = 1:L_m
				r = conv(r, r_m);
			end
			gamma = gamma(not(loc | locstr));
		end
	else
		r_m = [1, exp(alpha)*cosomega0];
		for ell = 1:L_m
			r = conv(r, r_m);
		end
		gamma = gamma(not(loc));
	end
end